[empathy] account-widget: don't display "Log in" button if we are modyfing an account



commit 5db0929af3f0b94d57ff21938ed49e2cfb0f4b88
Author: Guillaume Desmottes <guillaume desmottes collabora co uk>
Date:   Mon Feb 15 15:46:19 2010 +0000

    account-widget: don't display "Log in" button if we are modyfing an account
    
    Either the account is enabled and saving will reconnect, either it's not and
    that won't connect it.

 libempathy-gtk/empathy-account-widget.c |    8 +++++---
 1 files changed, 5 insertions(+), 3 deletions(-)
---
diff --git a/libempathy-gtk/empathy-account-widget.c b/libempathy-gtk/empathy-account-widget.c
index cbc2a1c..1367bf5 100644
--- a/libempathy-gtk/empathy-account-widget.c
+++ b/libempathy-gtk/empathy-account-widget.c
@@ -1436,9 +1436,10 @@ presence_changed_cb (TpAccountManager *manager,
     /* This button doesn't exist in 'simple' mode */
     return;
 
-  if (state > TP_CONNECTION_PRESENCE_TYPE_OFFLINE)
+  if (state > TP_CONNECTION_PRESENCE_TYPE_OFFLINE &&
+      priv->creating_account)
     {
       /* We are online, display a Login button */
       GtkWidget *image;
 
       gtk_button_set_use_stock (GTK_BUTTON (priv->apply_button), FALSE);
@@ -1450,7 +1451,8 @@ presence_changed_cb (TpAccountManager *manager,
     }
   else
     {
       /* We are offline, display a Save button */
       gtk_button_set_image (GTK_BUTTON (priv->apply_button), NULL);
       gtk_button_set_use_stock (GTK_BUTTON (priv->apply_button), TRUE);
       gtk_button_set_label (GTK_BUTTON (priv->apply_button), GTK_STOCK_SAVE);
@@ -1436,9 +1436,10 @@ presence_changed_cb (TpAccountManager *manager,
     {
-      /* We are online, display a Login button */
+      /* We are online and creating a new account, display a Login button */
       GtkWidget *image;
 
@@ -1450,7 +1451,8 @@ presence_changed_cb (TpAccountManager *manager,
   else
     {
-      /* We are offline, display a Save button */
+      /* We are offline or modifying an existing account, display
+       * a Save button */
       gtk_button_set_image (GTK_BUTTON (priv->apply_button), NULL);
       gtk_button_set_use_stock (GTK_BUTTON (priv->apply_button), TRUE);



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]